@@ -1,4 +1,8 @@
-from django.contrib.contenttypes import generic
+try:
+    from django.contrib.contenttypes.admin import GenericTabularInline
+except ImportError:
+    from django.contrib.contenttypes.generic import GenericTabularInline
+
 from django.contrib import admin
 from swingtime.models import *
 
@@ -7,11 +11,6 @@ class EventTypeAdmin(admin.ModelAdmin):
     list_display = ('label', 'abbr')
 
 
-#===============================================================================
-class NoteAdmin(admin.ModelAdmin):
-    list_display = ('note', 'created')
-
-
 #===============================================================================
 class OccurrenceInline(admin.TabularInline):
     model = Occurrence
@@ -19,7 +18,7 @@ class OccurrenceInline(admin.TabularInline):
 
 
 #===============================================================================
-class EventNoteInline(generic.GenericTabularInline):
+class EventNoteInline(GenericTabularInline):
     model = Note
     extra = 1
 
@@ -34,4 +33,3 @@ class EventAdmin(admin.ModelAdmin):
 
 admin.site.register(Event, EventAdmin)
 admin.site.register(EventType, EventTypeAdmin)
-admin.site.register(Note, NoteAdmin)
