@@ -3,7 +3,7 @@ Convenience forms for adding and updating ``Event`` and ``Occurrence``s.
 
 '''
 from datetime import datetime, date, time, timedelta
-
+from django import VERSION
 from django import forms
 from django.utils.translation import ugettext_lazy as _
 from django.forms.extras.widgets import SelectDateWidget
@@ -13,6 +13,8 @@ from swingtime.conf import settings as swingtime_settings
 from swingtime import utils
 from swingtime.models import *
 
+FIELDS_REQUIRED = (VERSION[:2] >= (1,6))
+
 WEEKDAY_SHORT = (
     (7, _(u'Sun')),
     (1, _(u'Mon')),
@@ -349,9 +351,9 @@ class MultipleOccurrenceForm(forms.Form):
             interval=data['interval'] or 1
         )
         
-        if self.cleaned_data['repeats'] == 'count':
+        if data['repeats'] == 'count':
             params['count'] = data['count']
-        elif self.cleaned_data['repeats'] == 'until':
+        elif data['repeats'] == 'until':
             params['until'] = data['until']
 
         if params['freq'] == rrule.WEEKLY:
@@ -388,6 +390,8 @@ class EventForm(forms.ModelForm):
     #===========================================================================
     class Meta:
         model = Event
+        if FIELDS_REQUIRED:
+            fields = "__all__"
         
     #---------------------------------------------------------------------------
     def __init__(self, *args, **kws):
@@ -408,5 +412,7 @@ class SingleOccurrenceForm(forms.ModelForm):
     #===========================================================================
     class Meta:
         model = Occurrence
+        if FIELDS_REQUIRED:
+            fields = "__all__"
         
 
