@@ -1,5 +1,4 @@
-from django.conf.urls.defaults import *
-
+from django.conf.urls import patterns, url
 from swingtime import views
 
 urlpatterns = patterns('',
